#
# spec file for package python-josepy
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define libname josepy
%{?sle15_python_module_pythons}
Name:           python-%{libname}
Version:        1.14.0
Release:        2.3
Summary:        JOSE protocol implementation in Python
License:        Apache-2.0
URL:            https://github.com/certbot/josepy
Source0:        https://files.pythonhosted.org/packages/source/j/%{libname}/%{libname}-%{version}.tar.gz
Source2:        %{name}.keyring
Patch1:         https://github.com/certbot/josepy/commit/350410fc1d38c4ac8422816b6865ac8cd9c60fc7.patch#/ignore-pyopenssl-warnings.patch
BuildRequires:  %{python_module base >= 3.7}
BuildRequires:  %{python_module coverage >= 4.0}
BuildRequires:  %{python_module cryptography >= 1.5}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module poetry >= 1.0.8}
BuildRequires:  %{python_module pyOpenSSL >= 0.13}
BuildRequires:  %{python_module pytest >= 2.8.0}
BuildRequires:  %{python_module setuptools >= 1.0}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-cryptography >= 1.5
Requires:       python-pyOpenSSL >= 0.13
Conflicts:      python-acme < 0.21.0
Obsoletes:      python-%{libname}-doc
BuildArch:      noarch
%python_subpackages

%description
JOSE protocol implementation in Python using cryptography.
It is used by the certbot project. Formerly Let's Encrypt project.

%prep
%autosetup -p1 -n %{libname}-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
# remove test-data
%python_expand rm -rf %{buildroot}%{$python_sitelib}/%{libname}/testdata
%python_expand rm -rf %{buildroot}%{$python_sitelib}/%{libname}/*_test.py*
%python_expand rm -rf %{buildroot}%{$python_sitelib}/%{libname}/**/*_test.py*
%python_expand rm -rf %{buildroot}%{$python_sitelib}/%{libname}/__pycache__/*_test*
# remove duplicates
%python_expand %fdupes %{buildroot}%{$python_sitelib}/%{libname}
# remove docfiles
%python_expand rm -rf %{buildroot}%{$python_sitelib}/CHANGELOG.rst
%python_expand rm -rf %{buildroot}%{$python_sitelib}/CONTRIBUTING.md

%check
%pytest

%files %{python_files}
%license LICENSE.txt
%doc CHANGELOG.rst CONTRIBUTING.md
%{python_sitelib}/%{libname}
%{python_sitelib}/%{libname}-%{version}.dist-info
%pycache_only %{python_sitelib}/%{libname}/__pycache__
# following the certbot-packaging guide, "jws" should not be packaged
%exclude %{_bindir}/jws

%changelog
* Mon Oct 28 2024 Dirk Müller <dmueller@suse.com>
- add ignore-pyopenssl-warnings.patch
* Wed Nov 29 2023 ecsos <ecsos@opensuse.org>
- Update to 1.14.0
  - Added support for Python 3.11 and 3.12.
  - Support for Python 3.7 has been deprecated and will be removed
    in the next scheduled release.
  - Dropped support for Python 3.6.
  - Added a new valid PGP key for signing our PyPI packages with
    the fingerprint F2871B4152AE13C49519111F447BF683AA3B26C3
- Comment out asc because no more found.
* Sun Jun 11 2023 ecsos <ecsos@opensuse.org>
- Add %%{?sle15_python_module_pythons}
* Thu Apr  7 2022 Markéta Machová <mmachova@suse.com>
- Update to 1.13.0
  * Added support for Python 3.10.
  * PGP keys used to sign the packages we upload to PyPI changed.
    (python-josepy.keyring refreshed)
  * Dropped support for cryptography<1.5.
  * Support for Python 3.6 has been deprecated and will be removed
    in the next scheduled release.
* Tue Oct  5 2021 ecsos <ecsos@opensuse.org>
- Update to 1.10.0
  * josepy is now compliant with PEP-561: type checkers will fetch
    types from the inline types annotations when josepy is
    installed as a dependency in a Python project.
  * Added a field function to assist in adding type annotations for
    Fields in classes. If the field function is used to define a
    Field in a JSONObjectWithFields based class without a type
    annotation, an error will be raised.
  * josepy's tests can no longer be imported under the name josepy,
    however, they are still included in the package and you can run
    them by installing josepy with "tests" extras and running
    python -m pytest.
- Changes from 1.9.0
  * Removed pytest-cache testing dependency.
  * Fixed a bug that sometimes caused incorrect padding to be used
    when serializing Elliptic Curve keys as JSON Web Keys.
* Sun May  9 2021 Dirk Müller <dmueller@suse.com>
- update to 1.8.0:
  * Removed external mock dependency.
  * Removed dependency on six.
  * Deprecated the module josepy.magic_typing.
  * Fix JWS/JWK generation with EC keys when keys or signatures have leading zeros.
* Mon Mar  8 2021 Dirk Müller <dmueller@suse.com>
- update to 1.7.0:
  * Dropped support for Python 2.7.
  * Added support for EC keys.
* Wed Jan  6 2021 Dirk Müller <dmueller@suse.com>
- update to 1.5.0:
  * Added support for Python 3.9.
  * Dropped support for Python 3.5.
  * Stopped supporting running tests with ``python setup.py test`` which is
    deprecated in favor of ``python -m pytest``.
  * Deprecated support for Python 3.5.
* Tue Mar 31 2020 Steve Kowalik <steven.kowalik@suse.com>
- Update to version 1.3.0:
  * Deprecated support for Python 3.4.
  * Officially add support for Python 3.8.
* Thu Oct 17 2019 Richard Brown <rbrown@suse.com>
- Remove obsolete Groups tag (fate#326485)
* Wed Jul 24 2019 pgajdos@suse.com
- version update to 1.2.0
  * Support for Python 2.6 and 3.3 has been removed.
  * Known incompatibilities with Python 3.8 have been resolved.
* Tue Jan 29 2019 Tomáš Chvátal <tchvatal@suse.com>
- Really run tests
- Disable docs building it is distributed by upstream and does not
  work on older openSUSE releases
* Thu May  3 2018 ecsos@opensuse.org
- update to 1.1.0
  - Deprecated support for Python 2.6 and 3.3.
  - Use the sign and verify methods when they are available in
    cryptography instead of the deprecated methods signer and
    verifier.
* Tue Jan 30 2018 jengelh@inai.de
- Use Documentation/* as RPM group for -doc.
* Sat Jan 27 2018 ecsos@opensuse.org
- initial version 1.0.1
